@@ -29,10 +29,6 @@ before 'BUILD' => sub {
 };
 
 # Public methods
-sub filtered_frames {
-   return grep { $_->subroutine !~ m{ :: __ANON__ \z }mx } $_[ 0 ]->frames;
-}
-
 sub message { # Stringify self and a full stack trace
    my $self = shift; return "${self}\n".$self->trace->as_string."\n";
 }
@@ -68,6 +64,8 @@ sub trace_frame_filter { # Lifted from StackTrace::Auto
       my  $subr    = $raw->{caller}->[ 3 ];
      (my  $package = $subr) =~ s{ :: \w+ \z }{}mx;
 
+      $ENV{UNEXPECTED_TRACE_BROKEN} and warn "$subr\n";
+
       if    ($found_mark == 3) { return 1 }
       elsif ($found_mark == 2) {
          # uncoverable branch true
@@ -134,13 +132,6 @@ A loadable class which defaults to L<Devel::StackTrace>
 
 =head1 Subroutines/Methods
 
-=head2 filtered_frames
-
-   @frames = $self->filtered_frames;
-
-Currently frames with subroutine names matching C<__ANON__> are
-filtered out
-
 =head2 message
 
    $error_text_and_stack_trace = $self->message;
